Exception: NwcRuby::UnsupportedMethodError
- Defined in:
- lib/nwc_ruby/errors.rb
Overview
The wallet service does not support the method we tried to call. Check ‘Client#capabilities` first, or use a read+write NWC string.
The wallet service does not support the method we tried to call. Check ‘Client#capabilities` first, or use a read+write NWC string.